==> versatile-kernel-2.6.18.1-compiled.tar.bz2: linux-2.6.18.1/drivers/scsi/st.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
};

static const struct modversion_info ____versions[]
__attribute_used__
__attribute__((section("__versions"))) = {
	{ 0xe3e52f33, "struct_module" },
	{ 0x99bb8806, "memmove" },
	{ 0x8320bea8, "__umodsi3" },
	{ 0x2f6b9290, "flush_dcache_page" },
	{ 0x350e2f4, "up_read" },
	{ 0xeb585a90, "get_user_pages" },
	{ 0x5ebb56fb, "down_read" },
	{ 0x12da5bb2, "__kmalloc" },
	{ 0xcb065951, "sysfs_create_link" },
	{ 0xde9cc24, "class_device_create_file" },
	{ 0xb3bbf481, "class_device_create" },
	{ 0xa75db628, "cdev_add" },
	{ 0x1a0a5914, "cdev_alloc" },
	{ 0x1d26aa98, "sprintf" },
	{ 0x3ae831b6, "kref_init" },
	{ 0x1075bf0, "panic" },
	{ 0xd0a46d42, "alloc_disk" },
	{ 0x12f237eb, "__kzalloc" },
	{ 0xadac503a, "dev_driver_string" },
	{ 0x84b183ae, "strncmp" },
	{ 0x97255bdf, "strlen" },
	{ 0x25b1dac, "driver_unregister" },
	{ 0x49d4e5be, "driver_remove_file" },
	{ 0x320b40d1, "class_destroy" },
	{ 0x7485e15e, "unregister_chrdev_region" },
	{ 0x9db33f18, "driver_create_file" },
	{ 0x88dc536f, "scsi_register_driver" },
	{ 0xd8e484f0, "register_chrdev_region" },
	{ 0x2d3f1dd1, "class_create" },
	{ 0x25da070, "snprintf" },
	{ 0xed33cbfd, "put_disk" },
	{ 0x8d09ff88, "cdev_del" },
	{ 0xdff32ed7, "class_device_destroy" },
	{ 0xe60c1553, "sysfs_remove_link" },
	{ 0x6e89c397, "scsi_device_get" },
	{ 0x8a1203a9, "kref_get" },
	{ 0xfb5e401, "mem_map" },
	{ 0x4265cd92, "contig_page_data" },
	{ 0x9809d7ee, "__alloc_pages" },
	{ 0x37ffa854, "scsi_cmd_ioctl" },
	{ 0x1042cbb5, "__up_wakeup" },
	{ 0x98082893, "__copy_to_user" },
	{ 0x7dceceac, "capable" },
	{ 0x17a142df, "__copy_from_user" },
	{ 0x2ebd083b, "scsi_nonblockable_ioctl" },
	{ 0x829871bc, "__down_interruptible_failed" },
	{ 0xcc5005fe, "msleep_interruptible" },
	{ 0x6b2dc060, "dump_stack" },
	{ 0x166bf2b6, "__free_pages" },
	{ 0xd2fb9a85, "scsi_block_when_processing_errors" },
	{ 0x8eb9004f, "put_page" },
	{ 0xf8d434ad, "scsi_ioctl" },
	{ 0xfa2a45e, "__memzero" },
	{ 0x211331fa, "__divsi3" },
	{ 0x9b05ea5c, "scsi_command_size" },
	{ 0xb13d73c9, "malloc_sizes" },
	{ 0x25fa6f17, "wait_for_completion" },
	{ 0xe8d0a30d, "scsi_execute_async" },
	{ 0x6cb34e5, "init_waitqueue_head" },
	{ 0xc818ff24, "kmem_cache_zalloc" },
	{ 0x37a0cba, "kfree" },
	{ 0xa218bf61, "complete" },
	{ 0x9d669763, "memcpy" },
	{ 0x69d38ed9, "__scsi_print_sense" },
	{ 0xdd132261, "printk" },
	{ 0x2b0ba2b0, "scsi_sense_desc_find" },
	{ 0x796fc5ce, "scsi_get_sense_info_fld" },
	{ 0xc65e73c, "scsi_normalize_sense" },
	{ 0x323222ba, "mutex_unlock" },
	{ 0x76f1b8cf, "scsi_device_put" },
	{ 0xcff53400, "kref_put" },
	{ 0xb97d4c9c, "mutex_lock" },
	{ 0x89b301d4, "param_get_int" },
	{ 0x98bd6f46, "param_set_int" },
};

static const char __module_depends[]
__attribute_used__
__attribute__((section(".modinfo"))) =
"depends=";

==> versatile-kernel-2.6.19.1-compiled.tar.bz2: linux-2.6.19.1/drivers/scsi/st.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
};

static const struct modversion_info ____versions[]
__attribute_used__
__attribute__((section("__versions"))) = {
	{ 0x528a560b, "struct_module" },
	{ 0x99bb8806, "memmove" },
	{ 0x8320bea8, "__umodsi3" },
	{ 0xf8b564a6, "flush_dcache_page" },
	{ 0x350e2f4, "up_read" },
	{ 0xcb868979, "get_user_pages" },
	{ 0x5ebb56fb, "down_read" },
	{ 0x12da5bb2, "__kmalloc" },
	{ 0xceb88836, "sysfs_create_link" },
	{ 0x2954bf, "class_device_create_file" },
	{ 0xaafc1419, "class_device_create" },
	{ 0x67da3e89, "cdev_add" },
	{ 0xa5abc2eb, "cdev_alloc" },
	{ 0x1d26aa98, "sprintf" },
	{ 0x3ae831b6, "kref_init" },
	{ 0x1075bf0, "panic" },
	{ 0xba36db29, "alloc_disk" },
	{ 0x12f237eb, "__kzalloc" },
	{ 0x6a304343, "dev_driver_string" },
	{ 0x84b183ae, "strncmp" },
	{ 0x97255bdf, "strlen" },
	{ 0xb99e33f0, "driver_create_file" },
	{ 0x9e9a022e, "scsi_register_driver" },
	{ 0xd8e484f0, "register_chrdev_region" },
	{ 0xa956b923, "class_create" },
	{ 0xb43dd575, "class_destroy" },
	{ 0x7485e15e, "unregister_chrdev_region" },
	{ 0x54eb4551, "driver_unregister" },
	{ 0x5a8135b, "driver_remove_file" },
	{ 0x25da070, "snprintf" },
	{ 0x5a44612c, "put_disk" },
	{ 0x2cb08b66, "cdev_del" },
	{ 0xc2bf2eb7, "class_device_destroy" },
	{ 0x16d6234, "sysfs_remove_link" },
	{ 0x40193e44, "scsi_device_get" },
	{ 0x8a1203a9, "kref_get" },
	{ 0x2f9838ed, "mem_map" },
	{ 0x2639095b, "contig_page_data" },
	{ 0xc7c16f53, "__alloc_pages" },
	{ 0x1592e44c, "scsi_cmd_ioctl" },
	{ 0x1042cbb5, "__up_wakeup" },
	{ 0x67c2fa54, "__copy_to_user" },
	{ 0x7dceceac, "capable" },
	{ 0xfbc74f64, "__copy_from_user" },
	{ 0x5a9322eb, "scsi_nonblockable_ioctl" },
	{ 0x829871bc, "__down_interruptible_failed" },
	{ 0xcc5005fe, "msleep_interruptible" },
	{ 0x6b2dc060, "dump_stack" },
	{ 0xd995807, "__free_pages" },
	{ 0xc9d27aaa, "scsi_block_when_processing_errors" },
	{ 0x20e229b, "put_page" },
	{ 0xa79d4acd, "scsi_ioctl" },
	{ 0xfa2a45e, "__memzero" },
	{ 0x211331fa, "__divsi3" },
	{ 0x9b05ea5c, "scsi_command_size" },
	{ 0xb13d73c9, "malloc_sizes" },
	{ 0x25fa6f17, "wait_for_completion" },
	{ 0x35eedf5f, "scsi_execute_async" },
	{ 0x6cb34e5, "init_waitqueue_head" },
	{ 0xc818ff24, "kmem_cache_zalloc" },
	{ 0x37a0cba, "kfree" },
	{ 0xa218bf61, "complete" },
	{ 0x9d669763, "memcpy" },
	{ 0x69d38ed9, "__scsi_print_sense" },
	{ 0xdd132261, "printk" },
	{ 0x2b0ba2b0, "scsi_sense_desc_find" },
	{ 0x796fc5ce, "scsi_get_sense_info_fld" },
	{ 0xc65e73c, "scsi_normalize_sense" },
	{ 0x323222ba, "mutex_unlock" },
	{ 0x147bf4aa, "scsi_device_put" },
	{ 0xcff53400, "kref_put" },
	{ 0xb97d4c9c, "mutex_lock" },
	{ 0x89b301d4, "param_get_int" },
	{ 0x98bd6f46, "param_set_int" },
};

static const char __module_depends[]
__attribute_used__
__attribute__((section(".modinfo"))) =
"depends=";
